@@ -27,10 +27,7 @@ import os.path
 import googletrans
 from colored import fore, style
 from googletrans import Translator
-
-
-TOOL = 'subtrs'
-VERSION = 1.4
+from __metadata__ import __prog__, __version__
 
 
 class Subtitles:
@@ -66,7 +63,7 @@ class Subtitles:
                 self.f = subs.readlines()
         except IOError:
             print(f'The file "{self.file}" does not exist')
-            raise SystemExit(1)
+            sys.exit(1)
 
     def write_new_subs(self):
         '''Write the new subtitle file'''
@@ -109,27 +106,25 @@ class Subtitles:
             self.translator.translate('Video', dest=lang).text
         except ValueError as Err:
             print(f'Error: {Err} "{lang}"')
-            raise SystemExit(1)
+            sys.exit(1)
 
 
 def usage(status):
     '''CLI help menu'''
-    args = ['Usage: subtrs [subtitles_file] [destination languages]',
-            ' ',
-            '       Simple tool that trlanslates video subtitles',
-            ' ',
+    args = ['Usage: subtrs [subtitles_file] [destination languages]\n',
+            '       Simple tool that trlanslates video subtitles\n',
             '       Support subtitles files [*.sbv, *.vtt, *.srt]',
-            '       Destination languages [en,de,ru] etc.',
-            ' ',
-            '       --color      Show translate text language with colour.',
-            '       --languages  Show all supported languages.',
+            '       Destination languages [en,de,ru] etc.\n',
+            'Optional arguments:',
+            '       --color      View translate text language with colour.',
             '       --silent     Silent method, without viewing.',
-            '       --version    Show the version and exit.',
-            '       --help       Show this message and exit.',
+            '  -l,  --languages  Show all supported languages.',
+            '  -v,  --version    Show the version and exit.',
+            '  -h,  --help       Show this message and exit.',
             ]
     for opt in args:
         print(opt)
-    raise SystemExit(status)
+    sys.exit(status)
 
 
 def args_flags(args):
@@ -137,7 +132,7 @@ def args_flags(args):
     flags = []
     if '--color' in args:
         args.remove('--color')
-        flags.append("--color")
+        flags.append('--color')
     if '--silent' in args:
         args.remove('--silent')
         flags.append('--silent')
@@ -152,19 +147,19 @@ def check_usage(args):
         usage(status=0)
 
     # Show the version and exit
-    if args[0] == '--version' and len(args) == 1:
-        print(f'{TOOL} version {VERSION}')
-        raise SystemExit(0)
+    if args[0] == '--version' or args[0] == '-v' and len(args) == 1:
+        print(f'{__prog__} version {__version__}')
+        sys.exit(0)
 
     # Show help menu and exit
-    if args[0] == '--help' and len(args) == 1:
+    if args[0] == '--help' or args[0] == '-h' and len(args) == 1:
         usage(status=0)
 
     # Show all suported languages
-    if args[0] == '--languages' and len(args) == 1:
+    if args[0] == '--languages' or args[0] == '-l' and len(args) == 1:
         for key, value in googletrans.LANGUAGES.items():
             print(key, value)
-        raise SystemExit()
+        sys.exit(0)
 
     # Check for subtitle extention file
     if args[0][-4:] not in file_ext:
